#!/bin/bash

# 配置时区
set_timezone() {
    if [ -n "$TZ" ]; then
        echo "正在设置时区为 $TZ..."
        ln -sf /usr/share/zoneinfo/$TZ /etc/localtime
        dpkg-reconfigure -f noninteractive tzdata
    else
        echo "未设置时区环境变量，使用默认时区..."
    fi
}

start_xrdp_services() {
    # 防止 xrdp 启动失败
    rm -rf /var/run/xrdp-sesman.pid
    rm -rf /var/run/xrdp.pid
    rm -rf /var/run/xrdp/xrdp-sesman.pid
    rm -rf /var/run/xrdp/xrdp.pid

    # 使用 exec 将信号转发到子进程
    xrdp-sesman && exec xrdp -n
}

stop_xrdp_services() {
    xrdp --kill
    xrdp-sesman --kill
    exit 0
}

echo "EntryPoint脚本正在运行..."
echo

# 设置时区
set_timezone

users=$(($#/3))
mod=$(($# % 3))

if [[ $# -eq 0 ]]; then 
    echo "没有输入参数，退出..."
    echo "每个用户应输入3个参数"
    exit
fi

if [[ $mod -ne 0 ]]; then 
    echo "输入错误，退出..."
    echo "每个用户应输入3个参数"
    exit
fi
echo "您输入了 $users 个用户"

while [ $# -ne 0 ]; do
    addgroup $1
    useradd -m -s /bin/bash -g $1 $1
    wait
    echo $1:$2 | chpasswd 
    wait
    if [[ $3 == "yes" ]]; then
        usermod -aG sudo $1
    fi
    wait
    echo "用户 '$1' 已添加"

    # 每次处理完3个参数后移位
    shift 3
done

echo -e "脚本执行完毕\n"

echo -e "开始启动 xrdp 服务...\n"

trap "stop_xrdp_services" SIGKILL SIGTERM SIGHUP SIGINT EXIT
start_xrdp_services